@@ -1,4 +1,4 @@
-# Copyright (c) 2009-2018 - Simon Conseil
+# Copyright (c) 2009-2020 - Simon Conseil
 
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to
@@ -18,7 +18,6 @@
 # FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 # IN THE SOFTWARE.
 
-import click
 import importlib
 import locale
 import logging
@@ -26,20 +25,26 @@ import os
 import socketserver
 import sys
 import time
-
-from click import argument, option
 from http import server
 
+import click
+from click import argument, option
+from pkg_resources import DistributionNotFound, get_distribution
+
 from .gallery import Gallery
 from .log import init_logging
-from .pkgmeta import __version__
 from .settings import read_settings
 from .utils import copy
 
-_DEFAULT_CONFIG_FILE = 'sigal.conf.py'
+try:
+    __version__ = get_distribution(__name__).version
+except DistributionNotFound:
+    # package is not installed
+    __version__ = None
 
-if sys.version_info[:2] < (3, 5):
-    raise Exception('Sigal supports Python 3.5+ only')
+__url__ = 'https://github.com/saimn/sigal'
+
+_DEFAULT_CONFIG_FILE = 'sigal.conf.py'
 
 
 @click.group()
@@ -69,7 +74,7 @@ def init(path):
 
     with open(path, 'w', encoding='utf-8') as f:
         f.write(conf.decode('utf8'))
-    print("Sample config file created: {}".format(path))
+    print(f"Sample config file created: {path}")
 
 
 @main.command()
@@ -79,23 +84,34 @@ def init(path):
         help="Force the reprocessing of existing images")
 @option('-v', '--verbose', is_flag=True, help="Show all messages")
 @option('-d', '--debug', is_flag=True,
-        help="Show all message, including debug messages")
+        help="Show all messages, including debug messages")
+@option('-q', '--quiet', is_flag=True, help="Show only error messages")
 @option('-c', '--config', default=_DEFAULT_CONFIG_FILE, show_default=True,
         help="Configuration file")
 @option('-t', '--theme', help="Specify a theme directory, or a theme name for "
         "the themes included with Sigal")
 @option('--title', help="Title of the gallery (overrides the title setting.")
 @option('-n', '--ncpu', help="Number of cpu to use (default: all)")
-def build(source, destination, debug, verbose, force, config, theme, title,
-          ncpu):
+def build(source, destination, debug, verbose, quiet, force, config, theme,
+          title, ncpu):
     """Run sigal to process a directory.
 
     If provided, 'source', 'destination' and 'theme' will override the
     corresponding values from the settings file.
 
     """
-    level = ((debug and logging.DEBUG) or (verbose and logging.INFO) or
-             logging.WARNING)
+    if sum([debug, verbose, quiet]) > 1:
+        sys.exit('Only one option of debug, verbose and quiet should be used')
+
+    if debug:
+        level = logging.DEBUG
+    elif verbose:
+        level = logging.INFO
+    elif quiet:
+        level = logging.ERROR
+    else:
+        level = logging.WARNING
+
     init_logging(__name__, level=level)
     logger = logging.getLogger(__name__)
 
@@ -137,7 +153,7 @@ def build(source, destination, debug, verbose, force, config, theme, title,
     locale.setlocale(locale.LC_ALL, settings['locale'])
     init_plugins(settings)
 
-    gal = Gallery(settings, ncpu=ncpu)
+    gal = Gallery(settings, ncpu=ncpu, quiet=quiet)
     gal.build(force=force)
 
     # copy extra files
@@ -145,7 +161,7 @@ def build(source, destination, debug, verbose, force, config, theme, title,
         src = os.path.join(settings['source'], src)
         dst = os.path.join(settings['destination'], dst)
         logger.debug('Copy %s to %s', src, dst)
-        copy(src, dst, symlink=settings['orig_link'])
+        copy(src, dst, symlink=settings['orig_link'], rellink=settings['rel_link'])
 
     stats = gal.stats
 
@@ -156,9 +172,10 @@ def build(source, destination, debug, verbose, force, config, theme, title,
         opt = ' ({})'.format(', '.join(opt)) if opt else ''
         return '{} {}s{}'.format(stats[_type], _type, opt)
 
-    print('Done.\nProcessed {} and {} in {:.2f} seconds.'
-          .format(format_stats('image'), format_stats('video'),
-                  time.time() - start_time))
+    if not quiet:
+        print('Done, processed {} and {} in {:.2f} seconds.'
+              .format(format_stats('image'), format_stats('video'),
+                      time.time() - start_time))
 
 
 def init_plugins(settings):
@@ -207,11 +224,11 @@ def serve(destination, port, config):
                          .format(destination=destination, config=config))
         sys.exit(2)
 
-    print('DESTINATION : {}'.format(destination))
+    print(f'DESTINATION : {destination}')
     os.chdir(destination)
     Handler = server.SimpleHTTPRequestHandler
     httpd = socketserver.TCPServer(("", port), Handler, False)
-    print(" * Running on http://127.0.0.1:{}/".format(port))
+    print(f" * Running on http://127.0.0.1:{port}/")
 
     try:
         httpd.allow_reuse_address = True
@@ -238,7 +255,7 @@ def set_meta(target, keys, overwrite=False):
     """
 
     if not os.path.exists(target):
-        sys.stderr.write("The target {} does not exist.\n".format(target))
+        sys.stderr.write(f"The target {target} does not exist.\n")
         sys.exit(1)
     if len(keys) < 2 or len(keys) % 2 > 0:
         sys.stderr.write("Need an even number of arguments.\n")
@@ -256,5 +273,5 @@ def set_meta(target, keys, overwrite=False):
     with open(descfile, "w") as fp:
         for i in range(len(keys) // 2):
             k, v = keys[i * 2:(i + 1) * 2]
-            fp.write("{}: {}\n".format(k.capitalize(), v))
+            fp.write(f"{k.capitalize()}: {v}\n")
     print("{} metadata key(s) written to {}".format(len(keys) // 2, descfile))
