@@ -1,4 +1,4 @@
-# Copyright (c) 2009-2018 - Simon Conseil
+# Copyright (c) 2009-2020 - Simon Conseil
 # Copyright (c) 2015 - François D.
 # Copyright (c) 2018 - Edwin Steele
 
@@ -29,22 +29,24 @@
 #
 # and partially modified. The code in question is licensed under MIT license.
 
+import fractions
 import logging
 import os
-import pilkit.processors
 import sys
 import warnings
-import fractions
-
 from copy import deepcopy
 from datetime import datetime
-from PIL.ExifTags import TAGS, GPSTAGS
-from PIL import Image as PILImage, ImageOps, ImageFile, IptcImagePlugin
+
+from PIL import Image as PILImage
+from PIL import ImageFile, ImageOps, IptcImagePlugin
+from PIL.ExifTags import GPSTAGS, TAGS
+
+import pilkit.processors
 from pilkit.processors import Transpose
 from pilkit.utils import save_image
 
 from . import signals, utils
-from .settings import get_thumb, Status
+from .settings import Status, get_thumb
 
 # Force loading of truncated files
 ImageFile.LOAD_TRUNCATED_IMAGES = True
@@ -55,6 +57,10 @@ def _has_exif_tags(img):
 
 
 def _read_image(file_path):
+    # The image is already opened
+    if isinstance(file_path, PILImage.Image):
+        return file_path
+
     with warnings.catch_warnings(record=True) as caught_warnings:
         im = PILImage.open(file_path)
 
@@ -105,7 +111,7 @@ def generate_image(source, outname, settings, options=None):
     if settings['autorotate_images']:
         try:
             img = Transpose().process(img)
-        except (IOError, IndexError):
+        except (OSError, IndexError):
             pass
 
     # Resize the image
@@ -132,7 +138,9 @@ def generate_image(source, outname, settings, options=None):
     for receiver in signals.img_resized.receivers_for(img):
         img = receiver(img, settings=settings)
 
-    outformat = img.format or original_format or 'JPEG'
+    # first, use hard-coded output format, or PIL format, or original image
+    # format, or fall back to JPEG
+    outformat = settings.get('img_format') or img.format or original_format or 'JPEG'
     logger.debug('Save resized image to %s (%s)', outname, outformat)
     save_image(img, outname, outformat, options=options, autoconvert=True)
 
@@ -195,15 +203,12 @@ def get_size(file_path):
     """Return image size (width and height)."""
     try:
         im = _read_image(file_path)
-    except (IOError, IndexError, TypeError, AttributeError) as e:
+    except (OSError, IndexError, TypeError, AttributeError) as e:
         logger = logging.getLogger(__name__)
         logger.error("Could not read size of %s due to %r", file_path, e)
     else:
         width, height = im.size
-        return {
-            'width': width,
-            'height': height
-        }
+        return {'width': width, 'height': height}
 
 
 def get_exif_data(filename):
@@ -268,6 +273,34 @@ def get_iptc_data(filename):
     return iptc_data
 
 
+def get_image_metadata(filename):
+    logger = logging.getLogger(__name__)
+    exif, iptc, size = {}, {}, {}
+
+    try:
+        img = _read_image(filename)
+    except Exception as e:
+        logger.error('Could not open image %s metadata: %s', filename, e)
+    else:
+        try:
+            if os.path.splitext(filename)[1].lower() in ('.jpg', '.jpeg'):
+                exif = get_exif_data(img)
+        except Exception as e:
+            logger.warning('Could not read EXIF data from %s: %s', filename, e)
+
+        try:
+            iptc = get_iptc_data(img)
+        except Exception as e:
+            logger.warning('Could not read IPTC data from %s: %s', filename, e)
+
+        try:
+            size = get_size(img)
+        except Exception as e:
+            logger.warning('Could not read size from %s: %s', filename, e)
+
+    return {'exif': exif, 'iptc': iptc, 'size': size}
+
+
 def dms_to_degrees(v):
     """Convert degree/minute/second to decimal degrees."""
 
@@ -285,10 +318,8 @@ def get_exif_tags(data, datetime_format='%c'):
 
     for tag in ('Model', 'Make', 'LensModel'):
         if tag in data:
-            if isinstance(data[tag], tuple):
-                simple[tag] = data[tag][0].strip()
-            else:
-                simple[tag] = data[tag].strip()
+            val = data[tag][0] if isinstance(data[tag], tuple) else data[tag]
+            simple[tag] = str(val).strip()
 
     if 'FNumber' in data:
         fnumber = data['FNumber']
