@@ -1,4 +1,4 @@
-# Copyright (c) 2009-2018 - Simon Conseil
+# Copyright (c) 2009-2020 - Simon Conseil
 # Copyright (c)      2014 - Jamie Starke
 
 # Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -32,9 +32,8 @@ previous/next :class:`~sigal.gallery.Media` objects.
 import os
 
 from sigal import signals
-from sigal.writer import AbstractWriter
 from sigal.utils import url_from_path
-from sigal.pkgmeta import __url__ as sigal_link
+from sigal.writer import AbstractWriter
 
 
 class PageWriter(AbstractWriter):
@@ -45,6 +44,7 @@ class PageWriter(AbstractWriter):
     def write(self, album, media_group):
         ''' Generate the media page and save it '''
 
+        from sigal import __url__ as sigal_link
         file_path = os.path.join(album.dst_path, media_group[0].filename)
 
         page = self.template.render({
