@@ -1,4 +1,4 @@
-# Copyright (c) 2009-2018 - Simon Conseil
+# Copyright (c) 2009-2020 - Simon Conseil
 # Copyright (c) 2013      - Christophe-Marie Duquesne
 # Copyright (c) 2017      - Mate Lakat
 
@@ -25,7 +25,6 @@ import os
 from os.path import abspath, isabs, join, normpath
 from pprint import pformat
 
-
 _DEFAULT_CONFIG = {
     'albums_sort_attr': 'name',
     'albums_sort_reverse': False,
@@ -42,6 +41,7 @@ _DEFAULT_CONFIG = {
     'img_extensions': ['.jpg', '.jpeg', '.png', '.gif'],
     'img_processor': 'ResizeToFit',
     'img_size': (640, 480),
+    'img_format': None,
     'index_in_url': False,
     'jpg_options': {'quality': 85, 'optimize': True, 'progressive': True},
     'keep_orig': False,
@@ -55,6 +55,7 @@ _DEFAULT_CONFIG = {
     'mp4_options': ['-crf', '23', '-strict', '-2'],
     'orig_dir': 'original',
     'orig_link': False,
+    'rel_link': False,
     'output_filename': 'index.html',
     'piwik': {'tracker_url': '', 'site_id': 0},
     'plugin_paths': [],
@@ -85,7 +86,7 @@ _DEFAULT_CONFIG = {
 }
 
 
-class Status(object):
+class Status:
     SUCCESS = 0
     FAILURE = 1
 
